@@ -3,6 +3,8 @@ use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
     'Dist::Zilla::Role::ModuleMetadata';
 
+use Module::Metadata 1.000022;
+
 sub metadata {
     my $self = shift;
     return +{
@@ -14,7 +16,7 @@ sub metadata {
                     # $modulename => { file => $filename, version => #version }
                     $_ => +{
                         file => $file->name,
-                        version => $mmd->version($_),
+                        version => $mmd->version($_)->stringify,
                     }
                 } grep { $_ ne 'main' } $mmd->packages_inside
             } grep { $_->name =~ /^lib\/.*\.pm$/} @{ $self->zilla->files }
